pub trait McBufErrorExt {
// Required method
fn is_only_lazy_left(&self) -> bool;
}Expand description
Extension methods for std::io::Error to be used with errors returned by McBufReader.
Required Methods
Sourcefn is_only_lazy_left(&self) -> bool
fn is_only_lazy_left(&self) -> bool
Returns true if this error represents the condition where there are only McBufReader::is_lazy readers
left, the buffer is drained and the inner reader is not EOF.
You can recover from this error by turning the reader non-lazy using McBufReader::set_lazy.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".