#[non_exhaustive]pub enum IpcReadHandle {
File(IpcFileHandle),
Bytes(IpcBytes),
}Expand description
File handle or allocated bytes that can be read after sending to another process.
Position
Read always starts from the beginning, the read methods seek the file start before returning. Note
that the read position is associated with the system handle, if you create multiple duplicates of the
same handle reading in one instance advances the position in all.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Implementations
Sourceimpl IpcReadHandle
impl IpcReadHandle
Sourcepub fn best_read_blocking(file: File) -> Result<Self>
pub fn best_read_blocking(file: File) -> Result<Self>
Either keep the handle or read to bytes, whichever is likely to be faster for the common usage pattern of sending to another process and a single full read with some seeking.
Sourcepub async fn best_read(file: File) -> Result<Self>
pub async fn best_read(file: File) -> Result<Self>
Either keep the handle or read to bytes, whichever is likely to be faster for the common usage pattern of sending to another process and a single full read with some seeking.
Sourcepub fn read_blocking(self) -> Result<IpcReadBlocking>
pub fn read_blocking(self) -> Result<IpcReadBlocking>
Begin reading using the std blocking API.
Sourcepub fn read_to_bytes_blocking(self) -> Result<IpcBytes>
pub fn read_to_bytes_blocking(self) -> Result<IpcBytes>
Read file to new IpcBytes or unwrap bytes.
Sourcepub async fn read_to_bytes(self) -> Result<IpcBytes>
pub async fn read_to_bytes(self) -> Result<IpcBytes>
Read file to new IpcBytes or unwrap bytes.
Sourcepub async fn duplicate_or_read(&mut self) -> Result<Self>
pub async fn duplicate_or_read(&mut self) -> Result<Self>
Attempts duplicate with read fallback.
If duplicate fails attempts read_to_bytes, if it succeeds replaces self with read bytes and returns a clone
if it fails replaces self with empty and returns the read error.
Sourcepub fn duplicate_or_read_blocking(&mut self) -> Result<Self>
pub fn duplicate_or_read_blocking(&mut self) -> Result<Self>
Attempts duplicate with read fallback.
If duplicate fails attempts read_to_bytes_blocking, if it succeeds replaces self with read bytes and returns a clone
if it fails replaces self with empty and returns the read error.