pub struct StderrTap(/* private fields */);Expand description
Record stderr of a child process while also passing though the output to the running process output.
Both blocking and async APIs are provided, the blocking API is slightly more efficient.
Implementations
Sourceimpl StderrTap
impl StderrTap
Sourcepub fn new_blocking(stream: ChildStderr) -> Self
pub fn new_blocking(stream: ChildStderr) -> Self
Start recording and passing.
Sourcepub fn new(stream: ChildStderr) -> Self
pub fn new(stream: ChildStderr) -> Self
Start recording and passing.
Sourcepub fn into_panic_blocking(self) -> Result<PanicInfo, Txt>
pub fn into_panic_blocking(self) -> Result<PanicInfo, Txt>
Block until the child process closes stderr and attempts to parse the last panic info from it.
If cannot find a panic returns Err with the captured stderr converted to Txt.
Note that the exit code for a fatal panic is 101, checking the exit code is the reliable
way to verify the child process exited due to panic.
Sourcepub async fn into_panic(self) -> Result<PanicInfo, Txt>
pub async fn into_panic(self) -> Result<PanicInfo, Txt>
Await until the child process closes stderr and attempts to parse the last panic info from it.
If cannot find a panic returns Err with the captured stderr converted to Txt.
Note that the exit code for a fatal panic is 101, checking the exit code is the reliable
way to verify the child process exited due to panic.
Sourceimpl StderrTap
impl StderrTap
Sourcepub fn into_string_blocking(self, remove_ansi_csi: bool) -> String
pub fn into_string_blocking(self, remove_ansi_csi: bool) -> String
Block until the child process closes the stream and converts the capture to String.
Sourcepub async fn into_string(self, remove_ansi_csi: bool) -> String
pub async fn into_string(self, remove_ansi_csi: bool) -> String
Await until the child process closes the stream and converts the capture to String.
Sourcepub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt
pub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt
Block until the child process closes the stream and converts the capture to Txt.