pub struct StdoutTap(/* private fields */);Expand description
Record stdout of a child process while also passing though the output to the running process output.
Both blocking and async APIs are provided, the blocking API is slightly more efficient.
Implementations
Sourceimpl StdoutTap
impl StdoutTap
Sourcepub fn new_blocking(stream: ChildStdout) -> Self
pub fn new_blocking(stream: ChildStdout) -> Self
Start recording and passing.
Sourcepub fn new(stream: ChildStdout) -> Self
pub fn new(stream: ChildStdout) -> Self
Start recording and passing.
Sourceimpl StdoutTap
impl StdoutTap
Sourcepub fn into_string_blocking(self, remove_ansi_csi: bool) -> String
pub fn into_string_blocking(self, remove_ansi_csi: bool) -> String
Block until the child process closes the stream and converts the capture to String.
Sourcepub async fn into_string(self, remove_ansi_csi: bool) -> String
pub async fn into_string(self, remove_ansi_csi: bool) -> String
Await until the child process closes the stream and converts the capture to String.
Sourcepub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt
pub fn into_txt_blocking(self, remove_ansi_csi: bool) -> Txt
Block until the child process closes the stream and converts the capture to Txt.