WorkerCrashError

Struct WorkerCrashError 

#[non_exhaustive]
pub struct WorkerCrashError { pub status: ExitStatus, pub stderr: Txt, }
Info about a worker process crash.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
status: ExitStatus

Worker process exit code.

stderr: Txt

Recorded stderr of the worker process.

Implementations

Source

impl WorkerCrashError

pub fn is_stderr_plain(&self) -> bool

Gets if stderr does not contain any ANSI scape sequences.

pub fn stderr_plain(&self) -> Txt

Get stderr without any ANSI escape sequences (CSI).

pub fn find_panic(&self) -> Option<PanicInfo>

Try parse stderr for the crash panic if exit code was 101.

Only reliably works if the panic fully printed correctly and was formatted by the panic hook installed by crash_handler or by the display print of PanicInfo.